@@ -1219,6 +1219,10 @@ response:
 
 		p_indent(level, frm);
 
+		uid = get_u16(frm);
+		printf("UIDCounter: 0x%04x (%u)\n", uid, uid);
+		break;
+	case AVRCP_EVENT_UIDS_CHANGED:
 		uid = get_u16(frm);
 		printf("UIDCounter: 0x%04x (%u)\n", uid, uid);
 		break;
@@ -1372,7 +1376,7 @@ static void avrcp_play_item_dump(int level, struct frame *frm,
 	if (ctype > AVC_CTYPE_GENERAL_INQUIRY)
 		goto response;
 
-	if (len < 13) {
+	if (len < 11) {
 		printf("PDU Malformed\n");
 		raw_dump(level, frm);
 		return;
@@ -1662,8 +1666,8 @@ static const char *playersubtype2str(uint32_t subtype)
 static void avrcp_media_player_item_dump(int level, struct frame *frm,
 								uint16_t len)
 {
-	uint16_t id, charset;
-	uint8_t type, status, namelen;
+	uint16_t id, charset, namelen;
+	uint8_t type, status;
 	uint32_t subtype;
 	uint64_t features[2];
 
@@ -1707,8 +1711,8 @@ static void avrcp_media_player_item_dump(int level, struct frame *frm,
 
 	p_indent(level, frm);
 
-	namelen = get_u8(frm);
-	printf("NameLength: 0x%02x (%u)\n", namelen, namelen);
+	namelen = get_u16(frm);
+	printf("NameLength: 0x%04x (%u)\n", namelen, namelen);
 
 	p_indent(level, frm);
 
@@ -1744,8 +1748,8 @@ static const char *foldertype2str(uint8_t type)
 
 static void avrcp_folder_item_dump(int level, struct frame *frm, uint16_t len)
 {
-	uint8_t type, playable, namelen;
-	uint16_t charset;
+	uint8_t type, playable;
+	uint16_t charset, namelen;
 	uint64_t uid;
 
 	p_indent(level, frm);
@@ -1777,8 +1781,8 @@ static void avrcp_folder_item_dump(int level, struct frame *frm, uint16_t len)
 
 	p_indent(level, frm);
 
-	namelen = get_u8(frm);
-	printf("NameLength: 0x%02x (%u)\n", namelen, namelen);
+	namelen = get_u16(frm);
+	printf("NameLength: 0x%04x (%u)\n", namelen, namelen);
 
 	p_indent(level, frm);
 
@@ -1841,8 +1845,10 @@ static void avrcp_media_element_item_dump(int level, struct frame *frm,
 								uint16_t len)
 {
 	uint64_t uid;
-	uint16_t charset;
-	uint8_t type, namelen, count;
+	uint16_t charset, namelen;
+	uint8_t type, count;
+
+	p_indent(level, frm);
 
 	if (len < 14) {
 		printf("PDU Malformed\n");
@@ -1865,8 +1871,8 @@ static void avrcp_media_element_item_dump(int level, struct frame *frm,
 
 	p_indent(level, frm);
 
-	namelen = get_u8(frm);
-	printf("NameLength: 0x%02x (%u)\n", namelen, namelen);
+	namelen = get_u16(frm);
+	printf("NameLength: 0x%04x (%u)\n", namelen, namelen);
 
 	p_indent(level, frm);
 
